@@ -1,7 +1,7 @@
 """
 Type annotations for codepipeline service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/literals.html)
 
 Usage::
 
@@ -44,11 +44,8 @@ __all__ = (
     "StageTransitionTypeType",
     "TriggerTypeType",
     "WebhookAuthenticationTypeType",
-    "CodePipelineServiceName",
     "ServiceName",
-    "ResourceServiceName",
     "PaginatorName",
-    "RegionName",
 )
 
 
@@ -96,7 +93,6 @@ TriggerTypeType = Literal[
     "Webhook",
 ]
 WebhookAuthenticationTypeType = Literal["GITHUB_HMAC", "IP", "UNAUTHENTICATED"]
-CodePipelineServiceName = Literal["codepipeline"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -385,18 +381,6 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
 PaginatorName = Literal[
     "list_action_executions",
     "list_action_types",
@@ -405,23 +389,3 @@ PaginatorName = Literal[
     "list_tags_for_resource",
     "list_webhooks",
 ]
-RegionName = Literal[
-    "ap-east-1",
-    "ap-northeast-1",
-    "ap-northeast-2",
-    "ap-south-1",
-    "ap-southeast-1",
-    "ap-southeast-2",
-    "ca-central-1",
-    "eu-central-1",
-    "eu-north-1",
-    "eu-south-1",
-    "eu-west-1",
-    "eu-west-2",
-    "eu-west-3",
-    "sa-east-1",
-    "us-east-1",
-    "us-east-2",
-    "us-west-1",
-    "us-west-2",
-]
